import{R as t}from"./Title.e3dcb8ea.js";import{F as d}from"./outputWidgets.c072fe4e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},f=new Error().stack;f&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[f]="cf4b8f7a-7b99-4b39-b58d-b71aef33c5df",e._sentryDebugIdIdentifier="sentry-dbid-cf4b8f7a-7b99-4b39-b58d-b71aef33c5df")}catch{}})();const r=d(t);export{r as A};
//# sourceMappingURL=index.2e3640f1.js.map
