import{d as g,ez as v,eA as k,r as b,b as r,c as s,w as a,u as e,f as l,ew as i}from"./outputWidgets.c072fe4e.js";import{S as w,L as j}from"./SmartConsole.9d135bfd.js";import{a as I}from"./asyncComputed.376cdc00.js";import{J as B}from"./jobs.50b17e33.js";import{_ as C}from"./SaveButton.vue_vue_type_script_setup_true_lang.1e48280b.js";import{_ as S}from"./DocsButton.vue_vue_type_script_setup_true_lang.afcf6cfa.js";import{B as T}from"./BaseLayout.bdaed231.js";import{_ as x,a as A}from"./JobSettings.vue_vue_type_script_setup_true_lang.152f25b0.js";import{c as D}from"./index.d808811c.js";import{A as _,T as R}from"./TabPane.df5f41ca.js";import"./forms.db17259c.js";import"./activeRecord.fdc25b97.js";import"./pubsub.98ad9fe0.js";import"./dashes.6f548a30.js";import"./index.00103e26.js";import"./hooks.bc826a67.js";import"./workspaces.921d369d.js";import"./icons.158b4825.js";import"./Title.e3dcb8ea.js";import"./index.2e3640f1.js";import"./uuid.d605f964.js";import"./ant-design.5cb2a38e.js";import"./RunButton.vue_vue_type_script_setup_true_lang.73f50f1c.js";import"./dayjs.a56ae918.js";import"./index.4e6af937.js";import"./Form.9f52866c.js";import"./index.ec8e038a.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[m]="e1c8d89d-3e2e-4d88-bd3a-3eb937224bc3",n._sentryDebugIdIdentifier="sentry-dbid-e1c8d89d-3e2e-4d88-bd3a-3eb937224bc3")}catch{}})();const ne=g({__name:"JobEditor",setup(n){const m=v(),c=k(),p=b(null),o=b("test");function y(){m.push({name:"jobs"})}const{result:t}=I(()=>B.get(c.params.jobId)),d=j.create();return($,f)=>(r(),s(T,null,{navbar:a(()=>[e(t)?(r(),s(e(D),{key:0,title:e(t).title,onBack:y},{footer:a(()=>[l(e(R),{"active-key":o.value,"onUpdate:activeKey":f[0]||(f[0]=u=>o.value=u)},{default:a(()=>[l(e(_),{key:"test",tab:"Test"}),l(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[l(S),o.value==="settings"?(r(),s(C,{key:0,model:e(t)},null,8,["model"])):i("",!0)]),_:1},8,["title"])):i("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(x,{key:0,ref_key:"tester",ref:p,job:e(t),"log-service":e(d)},null,8,["job","log-service"])):i("",!0),e(t)&&o.value==="settings"?(r(),s(A,{key:1,job:e(t)},null,8,["job"])):i("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(w,{key:0,runtime:"forms","log-service":e(d),onRestart:(u=p.value)==null?void 0:u.test},null,8,["log-service","onRestart"])):i("",!0)]}),_:1}))}});export{ne as default};
//# sourceMappingURL=JobEditor.eea1844d.js.map
