import{C as n}from"./Title.e3dcb8ea.js";import{F as d}from"./outputWidgets.c072fe4e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="097eee2f-2a6e-4922-8a80-85e3d190bcb3",e._sentryDebugIdIdentifier="sentry-dbid-097eee2f-2a6e-4922-8a80-85e3d190bcb3")}catch{}})();const f=d(n);export{f as A};
//# sourceMappingURL=index.d9c3e0de.js.map
