import{d as u,eA as f,J as b,b as y,c as _,u as g}from"./outputWidgets.c072fe4e.js";import{a as w}from"./asyncComputed.376cdc00.js";import"./console.a87f2a82.js";import{M as a}from"./member.78d15ad7.js";import"./index.90440471.js";import{_ as I}from"./CrudView.vue_vue_type_script_setup_true_lang.9296340f.js";import"./index.00103e26.js";import"./Form.9f52866c.js";import"./Title.e3dcb8ea.js";import"./CollapsePanel.ecfd8c73.js";import"./index.d808811c.js";import"./index.ec8e038a.js";import"./index.dce83dc7.js";import"./dayjs.a56ae918.js";import"./index.4e6af937.js";import"./index.8ab39784.js";import"./TabPane.df5f41ca.js";import"./index.c5fd7926.js";import"./index.148bcdd7.js";import"./index.d9c3e0de.js";import"./index.e5a5efcd.js";import"./index.e7c5574b.js";import"./index.96de14c0.js";import"./index.28ce0851.js";import"./index.2e3640f1.js";import"./index.4cff163b.js";import"./gateway.18ca6e0a.js";import"./activeRecord.fdc25b97.js";import"./pubsub.98ad9fe0.js";import"./icons.158b4825.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="e42587f0-dacb-4b40-8e39-c4e372dd8f71",e._sentryDebugIdIdentifier="sentry-dbid-e42587f0-dacb-4b40-8e39-c4e372dd8f71")}catch{}})();const X=u({__name:"Members",setup(e){const r=f().params.organizationId,n=[{key:"email",label:"Email"}],s=async t=>{await a.create(r,t.email),d()},{loading:p,result:l,refetch:d}=w(()=>a.list(r)),c=b(()=>{var t,i;return{columns:[{name:"Email"},{name:"Role"}],rows:(i=(t=l.value)==null?void 0:t.map(m=>({key:m.email,cells:[{text:m.email},{text:m.role}]})))!=null?i:[]}});return(t,i)=>(y(),_(I,{"entity-name":"members",loading:g(p),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:n,onCreate:s},null,8,["loading","table"]))}});export{X as default};
//# sourceMappingURL=Members.3398c42a.js.map
