.outline-button[data-v-d16448de]{cursor:pointer;display:flex;justify-content:center;align-items:center;padding:4px 8px;gap:8px;border-radius:4px;border:1px solid #d14056;font-weight:500;font-size:12px;color:#d14056;flex-shrink:0;box-shadow:1px 1px 3px #0000000f;background-color:transparent;box-sizing:border-box;height:26px}.outline-button .icon[data-v-d16448de]{height:16px;width:16px}.outline-button .icon[data-v-d16448de] path{fill:#d14056}.outline-button[data-v-d16448de]:hover{background:#f9fafb;color:#3267bd}.outline-button:hover .icon[data-v-d16448de] path{fill:#3267bd}.outline-button[data-v-d16448de]:active{background:#f9fafb;box-shadow:inset 1px 1px 2px #0000001a;border-color:transparent}.outline-button.disabled[data-v-d16448de]{cursor:unset;background:#f3f4f6;border:1px solid #bdc3cc;color:#bdc3cc}.outline-button.disabled[data-v-d16448de]:hover,.outline-button.disabled[data-v-d16448de]:active{background:#f3f4f6;box-shadow:none}.outline-button.disabled .icon[data-v-d16448de] path{fill:#bdc3cc}[data-v-9590d96b]:root{--main-font-family: DM Sans, sans-serif}[data-v-9590d96b]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-9590d96b]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-9590d96b]{background-color:#fff;padding:10px}.form-auto-fill-btn[data-v-9590d96b]{background-color:#fff!important}.hint[data-v-419a518f]{position:absolute;top:0;right:0;height:20px;width:20px;cursor:pointer;background-color:#333a;border-radius:50%}.hint path[data-v-419a518f]{fill:#f5f5f5}.hint .hint-content[data-v-419a518f]{display:none;background-color:#333d;color:#f5f5f5;padding:3px 5px;border-radius:4px;position:absolute;top:20px;left:20px;z-index:1;max-width:200px;text-align:left;font-size:.8rem;line-height:1.2rem}.hint:hover .hint-content[data-v-419a518f]{display:block}[data-v-1e8d2bdc]:root{--main-font-family: DM Sans, sans-serif}[data-v-1e8d2bdc]:root{--abstra-neutral-color: #bbb;--abstra-primary-color: #ffee56;--abstra-dark-text-color: #1b1b23;--abstra-normal-text-color: #414a58;--abstra-main-color-dark: #343b46;--abstra-main-color-light: #ffd84c;--abstra-secondary-color-dark: #4c5767;--abstra-secondary-color-light: #feab4c;--abstra-background-base: #f9fafb;--abstra-main-color-blue: #d14056}.p-dropdown[data-v-1e8d2bdc]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-1e8d2bdc]{background-color:#fff;padding:10px}.span-error[data-v-1e8d2bdc]{color:red;background:transparent;border-radius:.5rem;margin-top:10px}.sidebar-menu-icon[data-v-1e8d2bdc]{cursor:pointer;width:24px;height:24px;min-height:24px}.sidebar-menu-icon.disabled[data-v-1e8d2bdc]{pointer-events:none;visibility:hidden}.runner[data-v-1e8d2bdc]{position:relative}.runner.preview[data-v-1e8d2bdc]{height:100%}.runner[data-v-1e8d2bdc]:not(.preview){height:100vh}.form[data-v-1e8d2bdc]{padding:2rem 0 3rem}.widget[data-v-1e8d2bdc]{position:relative}.watermark[data-v-1e8d2bdc]{position:absolute;right:20px;bottom:0}.watermark.viewport-attached[data-v-1e8d2bdc]{position:fixed}.buttons[data-v-1e8d2bdc]{display:flex;flex-direction:row;gap:1rem;justify-content:flex-end;align-items:center;width:100%}.loading-wrapper[data-v-1e8d2bdc]{align-self:center}.auto-fill-btn[data-v-1e8d2bdc]{position:absolute;bottom:20px;left:20px}
