import{d as y,ez as g,eA as v,r as k,b as r,c as s,w as a,u as e,f as p,ew as n}from"./outputWidgets.c072fe4e.js";import{S as h,L as w}from"./SmartConsole.9d135bfd.js";import{a as B}from"./asyncComputed.376cdc00.js";import{H as C}from"./hooks.bc826a67.js";import{_ as H}from"./SaveButton.vue_vue_type_script_setup_true_lang.1e48280b.js";import{_ as I}from"./DocsButton.vue_vue_type_script_setup_true_lang.afcf6cfa.js";import{B as S}from"./BaseLayout.bdaed231.js";import{_ as T,a as x}from"./HookSettings.vue_vue_type_script_setup_true_lang.6dd458b0.js";import{c as A}from"./index.d808811c.js";import{A as _,T as D}from"./TabPane.df5f41ca.js";import"./forms.db17259c.js";import"./activeRecord.fdc25b97.js";import"./pubsub.98ad9fe0.js";import"./dashes.6f548a30.js";import"./index.00103e26.js";import"./jobs.50b17e33.js";import"./workspaces.921d369d.js";import"./icons.158b4825.js";import"./Title.e3dcb8ea.js";import"./index.2e3640f1.js";import"./uuid.d605f964.js";import"./ant-design.5cb2a38e.js";import"./StageRunSelector.vue_vue_type_script_setup_true_lang.3c5367b5.js";import"./RunButton.vue_vue_type_script_setup_true_lang.73f50f1c.js";import"./index.e5a5efcd.js";import"./index.e7c5574b.js";import"./CollapsePanel.ecfd8c73.js";import"./index.ec8e038a.js";import"./index.4e6af937.js";import"./Form.9f52866c.js";(function(){try{var i=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},m=new Error().stack;m&&(i._sentryDebugIds=i._sentryDebugIds||{},i._sentryDebugIds[m]="8eb00685-adb5-47de-9a9b-000b0cffc331",i._sentryDebugIdIdentifier="sentry-dbid-8eb00685-adb5-47de-9a9b-000b0cffc331")}catch{}})();const ue=y({__name:"HookEditor",setup(i){const m=g(),l=v(),c=k(null),o=k("test");function b(){m.push({name:"hooks"})}const{result:t}=B(()=>C.get(l.params.hookPath)),f=w.create();return(R,d)=>(r(),s(S,null,{navbar:a(()=>[e(t)?(r(),s(e(A),{key:0,title:e(t).title,onBack:b},{footer:a(()=>[p(e(D),{"active-key":o.value,"onUpdate:activeKey":d[0]||(d[0]=u=>o.value=u)},{default:a(()=>[p(e(_),{key:"test",tab:"Test"}),p(e(_),{key:"settings",tab:"Settings"})]),_:1},8,["active-key"])]),extra:a(()=>[p(I,{path:"hooks"}),o.value==="settings"?(r(),s(H,{key:0,model:e(t)},null,8,["model"])):n("",!0)]),_:1},8,["title"])):n("",!0)]),content:a(()=>[e(t)&&o.value==="test"?(r(),s(T,{key:0,ref_key:"tester",ref:c,hook:e(t),"log-service":e(f)},null,8,["hook","log-service"])):n("",!0),e(t)&&o.value==="settings"?(r(),s(x,{key:1,hook:e(t)},null,8,["hook"])):n("",!0)]),footer:a(()=>{var u;return[e(t)&&o.value==="test"?(r(),s(h,{key:0,runtime:"forms","log-service":e(f),onRestart:(u=c.value)==null?void 0:u.runHook},null,8,["log-service","onRestart"])):n("",!0)]}),_:1}))}});export{ue as default};
//# sourceMappingURL=HookEditor.ea1d8771.js.map
