import{d,eA as b,J as c,a as g,b as v,c as f,w as i,f as s}from"./outputWidgets.c072fe4e.js";import{B as _}from"./BaseLayout.bdaed231.js";import{a as h}from"./asyncComputed.376cdc00.js";import{P as y}from"./project.5033d689.js";import"./console.a87f2a82.js";import{O as z}from"./organization.09bd66c1.js";import"./index.90440471.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.b5ae2503.js";import{S as I}from"./Sidebar.03d9aa40.js";import{k as w,J as k,K as B,L as P,M as $,N as C,O as M,G as x,H as D,I as L}from"./icons.158b4825.js";import"./gateway.18ca6e0a.js";import"./activeRecord.fdc25b97.js";import"./pubsub.98ad9fe0.js";import"./index.00103e26.js";import"./Form.9f52866c.js";import"./Title.e3dcb8ea.js";import"./CollapsePanel.ecfd8c73.js";import"./index.d808811c.js";import"./index.ec8e038a.js";import"./index.dce83dc7.js";import"./dayjs.a56ae918.js";import"./index.4e6af937.js";import"./index.8ab39784.js";import"./TabPane.df5f41ca.js";import"./index.c5fd7926.js";import"./index.148bcdd7.js";import"./index.d9c3e0de.js";import"./index.e5a5efcd.js";import"./index.e7c5574b.js";import"./index.96de14c0.js";import"./index.28ce0851.js";import"./index.2e3640f1.js";import"./index.4cff163b.js";import"./logo.084e5d7c.js";import"./Tooltip.f9ca606b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="005cdbcb-285a-4313-aa7b-a81a8c588a59",t._sentryDebugIdIdentifier="sentry-dbid-005cdbcb-285a-4313-aa7b-a81a8c588a59")}catch{}})();const ga=d({__name:"Project",setup(t){const p=b().params.projectId,{result:a}=h(()=>y.get(p).then(async o=>{const e=await z.get(o.organizationId);return{project:o,organization:e}})),l=c(()=>{var o,e,r,m;return((o=a.value)==null?void 0:o.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(r=(e=a.value)==null?void 0:e.organization)==null?void 0:r.name,path:`/organizations/${(m=a.value)==null?void 0:m.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=c(()=>{var o;return(o=a.value)!=null&&o.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:k},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:$},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:x,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:D,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:L,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(o,e)=>{const r=g("router-view");return v(),f(_,null,{content:i(()=>[s(r)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{ga as default};
//# sourceMappingURL=Project.a3adfc61.js.map
