import{x as o,a,b as i,c,g as p,h as d,_,i as u,T as f,j as l,P as b,C as h,M as m,s as y,k as s,l as g,m as v,n as w,p as I}from"./outputWidgets.c072fe4e.js";import{u as k}from"./index.ad809a50.js";import"./pubsub.98ad9fe0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f5b867d3-929c-4e7b-87b2-87b9b5af3ff2",e._sentryDebugIdIdentifier="sentry-dbid-f5b867d3-929c-4e7b-87b2-87b9b5af3ff2")}catch{}})();const x={};function A(e,t){const r=a("router-view");return i(),c(r,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const D=o(x,[["render",A]]),n=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.7f0402cf.js"),["assets/Player.7f0402cf.js","assets/index.00103e26.js","assets/outputWidgets.c072fe4e.js","assets/outputWidgets.8ce475af.css","assets/uuid.d605f964.js","assets/broker.edfeca40.js","assets/index.ad809a50.js","assets/pubsub.98ad9fe0.js","assets/executeJs.9d1a076f.js","assets/icons.158b4825.js","assets/CircularLoading.1db5d4d0.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.26f9089b.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.1df0e634.js","assets/Steps.998aa76d.css","assets/Modal.dfafcf8c.js","assets/Modal.5aaf8eba.css","assets/executeJs.dfa3b35d.css","assets/WidgetsFrame.6a9a3802.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.abbded52.js","assets/broker.ac4594bd.css","assets/DashPlayer.74f2acef.js","assets/geometryUtils.c951785a.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.376cdc00.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class P{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}(async()=>{await k();const e=u({render:()=>g(D)});f.init(),l(e,n),P.init(),e.use(n),e.use(b),e.mount("#app"),e.component("VSelect",h),e.component("Markdown",m),e.component("Message",y),s(e,v),s(e,w),s(e,I)})();
//# sourceMappingURL=player.64d8e3e6.js.map
