import{M as a}from"./Modal.dfafcf8c.js";import{d as r,H as d,r as c,a as _,b as f,et as l,f as n,w as i,bg as m,e as u,x as p}from"./outputWidgets.c072fe4e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ddc1079f-499d-4e19-b1a4-ceaffabd1f75",e._sentryDebugIdIdentifier="sentry-dbid-ddc1079f-499d-4e19-b1a4-ceaffabd1f75")}catch{}})();const b=["src"],y=r({__name:"Home",setup(e){const o=d({onboardingForm:""}),t=c(null);return(g,w)=>{const s=_("router-view");return f(),l(m,null,[n(s,{class:"router"}),n(a,{ref_key:"modal",ref:t},{content:i(()=>[u("iframe",{class:"form",src:o.onboardingForm},null,8,b)]),_:1},512)],64)}}});const I=p(y,[["__scopeId","data-v-7e290e34"]]);export{I as default};
//# sourceMappingURL=Home.1482aca0.js.map
