import{x as t,b as s,et as o}from"./outputWidgets.c072fe4e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4cedbe85-7de8-4b2e-b381-f7512821032a",e._sentryDebugIdIdentifier="sentry-dbid-4cedbe85-7de8-4b2e-b381-f7512821032a")}catch{}})();const r={},d={class:"organization-settings"};function i(e,n){return s(),o("div",d,"Organization settings")}const f=t(r,[["render",i]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.2e4754a5.js.map
