import{S as p}from"./Sidebar.03d9aa40.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.b5ae2503.js";import{G as l,H as d,I as u}from"./icons.158b4825.js";import{d as b,eA as f,J as g,a as _,b as y,c as v,w as e,f as a}from"./outputWidgets.c072fe4e.js";import{a as w}from"./asyncComputed.376cdc00.js";import"./console.a87f2a82.js";import{O as z}from"./organization.09bd66c1.js";import"./index.90440471.js";import{B as h}from"./BaseLayout.bdaed231.js";import"./Tooltip.f9ca606b.js";import"./logo.084e5d7c.js";import"./index.4cff163b.js";import"./Title.e3dcb8ea.js";import"./index.ec8e038a.js";import"./index.d808811c.js";import"./index.00103e26.js";import"./Form.9f52866c.js";import"./CollapsePanel.ecfd8c73.js";import"./index.dce83dc7.js";import"./dayjs.a56ae918.js";import"./index.4e6af937.js";import"./index.8ab39784.js";import"./TabPane.df5f41ca.js";import"./index.c5fd7926.js";import"./index.148bcdd7.js";import"./index.d9c3e0de.js";import"./index.e5a5efcd.js";import"./index.e7c5574b.js";import"./index.96de14c0.js";import"./index.28ce0851.js";import"./index.2e3640f1.js";import"./gateway.18ca6e0a.js";import"./activeRecord.fdc25b97.js";import"./pubsub.98ad9fe0.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="e490bf83-ce83-482b-909f-2e82d310acb7",o._sentryDebugIdIdentifier="sentry-dbid-e490bf83-ce83-482b-909f-2e82d310acb7")}catch{}})();const io=b({__name:"Organization",setup(o){const i=f().params.organizationId,{result:r}=w(()=>z.get(i)),n=g(()=>r.value?[{label:"My organizations",path:"/organizations"},{label:r.value.name,path:`/organizations/${r.value.id}`}]:void 0),m=[{name:"Organization",items:[{name:"Projects",icon:l,path:"projects"},{name:"Members",icon:d,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const s=_("router-view");return y(),v(h,null,{navbar:e(()=>[a(c,{breadcrumb:n.value},null,8,["breadcrumb"])]),sidebar:e(()=>[a(p,{class:"sidebar",sections:m})]),content:e(()=>[a(s)]),_:1})}}});export{io as default};
//# sourceMappingURL=Organization.93eaafbd.js.map
