import{d as o,b as a,c as r,w as c,aJ as i,u as d,c4 as p}from"./outputWidgets.c072fe4e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="1561b24f-8c95-4cdc-800a-b176b616840a",t._sentryDebugIdIdentifier="sentry-dbid-1561b24f-8c95-4cdc-800a-b176b616840a")}catch{}})();class f{async get(){return(await fetch("/_editor/api/login")).json()}async create(e){return(await fetch("/_editor/api/login",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({token:e})})).json()}async delete(){await fetch("/_editor/api/login",{method:"DELETE"})}}const u=new f,b=o({__name:"DocsButton",props:{path:{}},setup(t){return(e,n)=>{var s;return a(),r(d(p),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank"},{default:c(()=>[i(" Docs ")]),_:1},8,["href"])}}});export{b as _,u as l};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.afcf6cfa.js.map
