import{_ as I}from"./logo.084e5d7c.js";import{x as B,b as s,et as y,eD as C,eE as w,e as h,d as k,ez as L,a as D,u as e,c,bF as S,w as t,f as o,aJ as d,eC as _,c4 as f,cI as N,t as V,eB as E,eZ as R,bg as T,ew as F}from"./outputWidgets.c072fe4e.js";import{a as b}from"./console.a87f2a82.js";import{a as P}from"./asyncComputed.376cdc00.js";import{a as $}from"./index.4cff163b.js";import{A as g}from"./index.ec8e038a.js";import{A as j,B as z,a as H,c as J}from"./index.d808811c.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="18d3f5cd-6ea5-4dc4-866c-4b2e22a1b2c5",a._sentryDebugIdIdentifier="sentry-dbid-18d3f5cd-6ea5-4dc4-866c-4b2e22a1b2c5")}catch{}})();const M={},v=a=>(C("data-v-439be421"),a=a(),w(),a),U={class:"logo"},Z=v(()=>h("img",{class:"logo-img",src:I,alt:"Abstra cloud logo"},null,-1)),q=v(()=>h("span",null,"Abstra Cloud",-1)),G=[Z,q];function K(a,r){return s(),y("div",U,G)}const O=B(M,[["render",K],["__scopeId","data-v-439be421"]]),Q=k({__name:"LoginBlock",setup(a){function r(p){const m=p.split("@")[0];return V.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(i=>i[0]).join("")}const l=L(),{result:n,loading:u,refetch:x}=P(async()=>b.getAuthor());function A(){b.removeAuthor(),x(),l.push({name:"login"})}return(p,m)=>{const i=D("router-link");return e(u)?(s(),c(e(S),{key:0})):e(n)?(s(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(g),{direction:"vertical"},{default:t(()=>[o(e($),null,{default:t(()=>[d(_(e(n).claims.email),1)]),_:1}),o(e(f),{onClick:A},{default:t(()=>[d("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(g),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e(j),null,{default:t(()=>[d(_(r(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(s(),c(e(f),{key:2},{default:t(()=>[o(i,{to:"/login"},{default:t(()=>[d("Login")]),_:1})]),_:1}))}}}),re=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(r,l)=>(s(),c(e(J),{style:{padding:"5px 10px"}},{breadcrumb:t(()=>[r.breadcrumb?(s(),c(e(z),{key:0},{default:t(()=>[(s(!0),y(T,null,E(r.breadcrumb,(n,u)=>(s(),c(e(H),{key:u},{default:t(()=>[o(e(R),{to:n.path},{default:t(()=>[d(_(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[o(O)]),extra:t(()=>[o(Q)]),_:1}))}});export{re as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.b5ae2503.js.map
